---
name: Bug report
about: Let us know if something is broken on PySGN

---

**Describe the bug**
<!-- A clear and concise description the bug -->

**Expected behavior**
<!-- A clear and concise description of what you expected to happen -->

**To Reproduce**
<!-- Steps to reproduce the bug, or a link to a project where the bug is visible -->

**Additional context**
<!--
    Add any other context here.
    Any details about your specific platform:
    * If the problem is in the browser, what browser, version, and OS?
-->